==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/S27bb93620543a5474aa4d6e96306e7df.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 
#ifndef S39362924d87488df5a3a11a87b05b966
 
#define S39362924d87488df5a3a11a87b05b966
 
#include "Se212bcaaa6416f3692b6fa96bb03af95.h"

#include "S6a23cd91a4e21dfddbc34fdc3cc334d3.h"
 class S51714db021d27b897dbb8d7320584911 { public: S8fe59ef6e1e9f87740040549ec149682 Se0d22b0061649fe28e0d7f409635c372; 
long Sa0de5ed069c688d15fc87b1a1c27597a; S52b2679e781be36a71722155fcceae42 S70dda5dfb8053dc6d1c492574bce9bfd; 
const char *S7ecd5e34057e2a40ddf4ed2043f26a11; unsigned long S70ffd93d669ae5f2d9833b3fd696a6bf; S51714db021d27b897dbb8d7320584911(void): 
Se0d22b0061649fe28e0d7f409635c372(0, 0, 0, 0), Sa0de5ed069c688d15fc87b1a1c27597a(0), S70ffd93d669ae5f2d9833b3fd696a6bf(0) 
{ S7ecd5e34057e2a40ddf4ed2043f26a11 = NULL; } S51714db021d27b897dbb8d7320584911(unsigned long S46ab2997ca006d78b35db8f6f9de7662, 
unsigned long S16b963ddf15f70d9c09871cc3e103dd0, double S4b3a6218bb3e3a7303e8a171a60fcf92, unsigned 
long Sf24d2cc05ca7eaa87d0959ea3f5ddfb2): Se0d22b0061649fe28e0d7f409635c372(S46ab2997ca006d78b35db8f6f9de7662, 
S16b963ddf15f70d9c09871cc3e103dd0, S4b3a6218bb3e3a7303e8a171a60fcf92, Sf24d2cc05ca7eaa87d0959ea3f5ddfb2), 
Sa0de5ed069c688d15fc87b1a1c27597a(0), S70ffd93d669ae5f2d9833b3fd696a6bf(0) { S7ecd5e34057e2a40ddf4ed2043f26a11 
= NULL; } S51714db021d27b897dbb8d7320584911 &operator =(const S51714db021d27b897dbb8d7320584911 &Sd8d1e71d768e975acf55cb45eab7f5ea) 
{ Se0d22b0061649fe28e0d7f409635c372 = Sd8d1e71d768e975acf55cb45eab7f5ea.Se0d22b0061649fe28e0d7f409635c372; 
S70dda5dfb8053dc6d1c492574bce9bfd = Sd8d1e71d768e975acf55cb45eab7f5ea.S70dda5dfb8053dc6d1c492574bce9bfd; 
S7ecd5e34057e2a40ddf4ed2043f26a11 = Sd8d1e71d768e975acf55cb45eab7f5ea.S7ecd5e34057e2a40ddf4ed2043f26a11; 
return *this; } }; 
#endif

==> sawmill6.4.5_crypt_src.tar.gz: sawmill-6.4.5/S27bb93620543a5474aa4d6e96306e7df.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#ifndef S39362924d87488df5a3a11a87b05b966
 
#define S39362924d87488df5a3a11a87b05b966
 
#include "Se212bcaaa6416f3692b6fa96bb03af95.h"

#include "S6a23cd91a4e21dfddbc34fdc3cc334d3.h"

#include "S749d2b576e15d77f0d14f186077e9ace.h"
 class S51714db021d27b897dbb8d7320584911 { public: S8fe59ef6e1e9f87740040549ec149682 Se0d22b0061649fe28e0d7f409635c372; 
long Sa0de5ed069c688d15fc87b1a1c27597a; S52b2679e781be36a71722155fcceae42 S70dda5dfb8053dc6d1c492574bce9bfd; 
 S749d2b576e15d77f0d14f186077e9ace S7ecd5e34057e2a40ddf4ed2043f26a11; unsigned long S70ffd93d669ae5f2d9833b3fd696a6bf; 
S51714db021d27b897dbb8d7320584911(void): Se0d22b0061649fe28e0d7f409635c372(0, 0, 0, 0), Sa0de5ed069c688d15fc87b1a1c27597a(0), 
S70ffd93d669ae5f2d9833b3fd696a6bf(0) { S7ecd5e34057e2a40ddf4ed2043f26a11 = ""; } S51714db021d27b897dbb8d7320584911(unsigned 
long S46ab2997ca006d78b35db8f6f9de7662, unsigned long S16b963ddf15f70d9c09871cc3e103dd0, double S4b3a6218bb3e3a7303e8a171a60fcf92, 
unsigned long Sf24d2cc05ca7eaa87d0959ea3f5ddfb2): Se0d22b0061649fe28e0d7f409635c372(S46ab2997ca006d78b35db8f6f9de7662, 
S16b963ddf15f70d9c09871cc3e103dd0, S4b3a6218bb3e3a7303e8a171a60fcf92, Sf24d2cc05ca7eaa87d0959ea3f5ddfb2), 
Sa0de5ed069c688d15fc87b1a1c27597a(0), S70ffd93d669ae5f2d9833b3fd696a6bf(0) { S7ecd5e34057e2a40ddf4ed2043f26a11 
= ""; } S51714db021d27b897dbb8d7320584911 &operator =(const S51714db021d27b897dbb8d7320584911 &Sd8d1e71d768e975acf55cb45eab7f5ea) 
{ Se0d22b0061649fe28e0d7f409635c372 = Sd8d1e71d768e975acf55cb45eab7f5ea.Se0d22b0061649fe28e0d7f409635c372; 
S70dda5dfb8053dc6d1c492574bce9bfd = Sd8d1e71d768e975acf55cb45eab7f5ea.S70dda5dfb8053dc6d1c492574bce9bfd; 
S7ecd5e34057e2a40ddf4ed2043f26a11 = Sd8d1e71d768e975acf55cb45eab7f5ea.S7ecd5e34057e2a40ddf4ed2043f26a11; 
return *this; } }; 
#endif
